@@ -9,7 +9,7 @@ vector of probabilities.
 from numpy import cumsum
 from numpy.random import uniform
 
-class discreteRV(object):
+class DiscreteRV(object):
     """
     Generates an array of draws from a discrete random variable with vector of
     probabilities given by q.  
