@@ -1,10 +1,8 @@
 """
-Origin: QE by John Stachurski and Thomas J. Sargent
 Filename: lqcontrol.py
 Authors: John Stachurski and Thomas J. Sargent
-LastModified: 12/09/2013
 
-Solves LQ control problems.
+Provides a class called LQ for solving linear quadratic control problems.
 """
 
 import numpy as np
@@ -133,7 +131,8 @@ class LQ:
 
             V(x) = x' P x + d
 
-        Also computes the control matrix F from u = - Fx
+        in the infinite horizon case.  Also computes the control matrix F from
+        u = - Fx
 
         """
         # === simplify notation === #
